translate.convert.po2tmx.TmxOptionParser

Package translate :: Package convert :: Module po2tmx :: Class TmxOptionParser |
[hide private]
[frames] | no frames]

# Class TmxOptionParser

source code

Instance Methods | [hide private]
recursiveprocess(self, options) recurse through directories and convert files | source code
Inherited from `convert.ArchiveConvertOptionParser`: `__init__`, `checkoutputsubdir`, `getarchiveclass`, `getfullinputpath`, `getfulloutputpath`, `getfulltemplatepath`, `initoutputarchive`, `inittemplatearchive`, `isarchive`, `isrecursive`, `openarchive`, `openinputfile`, `openoutputfile`, `opentemplatefile`, `processfile`, `recursearchivefiles`, `recurseinputfiles`, `setarchiveoptions`, `templateexists` Inherited from `convert.ConvertOptionParser`: `add_duplicates_option`, `add_fuzzy_option`, `add_multifile_option`, `filterinputformats`, `filteroutputoptions`, `getformathelp`, `potifyformat`, `run`, `setpotoption`, `verifyoptions` Inherited from `misc.optrecurse.RecursiveOptionParser`: `define_option`, `finalizetempoutputfile`, `format_manpage`, `get_prog_name`, `getoutputname`, `getoutputoptions`, `getpassthroughoptions`, `gettemplatename`, `getusageman`, `getusagestring`, `initprogressbar`, `isexcluded`, `isvalidinputname`, `mkdir`, `opentempoutputfile`, `parse_args`, `print_manpage`, `recurseinputfilelist`, `reportprogress`, `set_usage`, `seterrorleveloptions`, `setformats`, `setmanpageoption`, `setprogressoptions`, `setpsycooption`, `splitext`, `splitinputext`, `splittemplateext`, `usepsyco`, `warning` Inherited from `optparse.OptionParser`: `add_option_group`, `check_values`, `destroy`, `disable_interspersed_args`, `enable_interspersed_args`, `error`, `exit`, `expand_prog_name`, `format_epilog`, `format_help`, `format_option_help`, `get_default_values`, `get_description`, `get_option_group`, `get_usage`, `get_version`, `print_help`, `print_usage`, `print_version`, `set_default`, `set_defaults`, `set_process_default_values` Inherited from `optparse.OptionParser` (private): `_add_help_option`, `_add_version_option`, `_create_option_list`, `_get_all_options`, `_get_args`, `_get_encoding`, `_init_parsing_state`, `_match_long_opt`, `_populate_option_list`, `_process_args`, `_process_long_opt`, `_process_short_opts` Inherited from `optparse.OptionContainer`: `add_option`, `add_options`, `format_description`, `get_option`, `has_option`, `remove_option`, `set_conflict_handler`, `set_description` Inherited from `optparse.OptionContainer` (private): `_check_conflict`, `_create_option_mappings`, `_share_option_mappings` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `optparse.OptionParser`: `standard_option_list`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### recursiveprocess(self, options) | source code
recurse through directories and convert files Overrides: misc.optrecurse.RecursiveOptionParser.recursiveprocess (inherited documentation)